==> jc-1.4.0.tar.gz: soot/BodyTransformer.h <==
// public abstract class soot.BodyTransformer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer

// header file dependencies
// @dep_header soot_Transformer

#include "soot/Transformer.h"

#ifndef _JC_soot_BodyTransformer_H_
#define _JC_soot_BodyTransformer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;

// Typedefs
typedef struct _jc_soot_BodyTransformer$sub_refs	_jc_soot_BodyTransformer$sub_refs;
typedef struct _jc_soot_BodyTransformer$sub_nonrefs	_jc_soot_BodyTransformer$sub_nonrefs;
typedef struct _jc_soot_BodyTransformer$refs	_jc_soot_BodyTransformer$refs;
typedef struct _jc_soot_BodyTransformer$nonrefs	_jc_soot_BodyTransformer$nonrefs;
typedef struct _jc_soot_BodyTransformer$object	_jc_soot_BodyTransformer$object;

typedef const struct _jc_soot_BodyTransformer$vmethods	_jc_soot_BodyTransformer$vmethods;
typedef const struct _jc_soot_BodyTransformer$vtable	_jc_soot_BodyTransformer$vtable;
typedef const struct _jc_soot_BodyTransformer$vtype	_jc_soot_BodyTransformer$vtype;

// Constructors
extern void _jc_soot_BodyTransformer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_BodyTransformer$object *);

// Virtual methods
extern void _jc_soot_BodyTransformer$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_BodyTransformer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_soot_BodyTransformer$method$transform$efe210b8710809f9(_jc_env *, struct _jc_soot_BodyTransformer$object *, struct _jc_soot_Body$object *);
extern void _jc_soot_BodyTransformer$method$transform$6c1afdd3773c7636(_jc_env *, struct _jc_soot_BodyTransformer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *);
extern void _jc_soot_BodyTransformer$method$transform$fa83af6c18402119(_jc_env *, struct _jc_soot_BodyTransformer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_BodyTransformer$method_info$internalTransform$9abd4924859b68a3;
extern _jc_method _jc_soot_BodyTransformer$method_info$transform$efe210b8710809f9;
extern _jc_method _jc_soot_BodyTransformer$method_info$transform$6c1afdd3773c7636;
extern _jc_method _jc_soot_BodyTransformer$method_info$transform$fa83af6c18402119;

// Virtual methods structure
struct _jc_soot_BodyTransformer$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_BodyTransformer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	void	(*transform$efe210b8710809f9)(_jc_env *, struct _jc_soot_BodyTransformer$object *, struct _jc_soot_Body$object *);
	void	(*transform$6c1afdd3773c7636)(_jc_env *, struct _jc_soot_BodyTransformer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *);
	void	(*transform$fa83af6c18402119)(_jc_env *, struct _jc_soot_BodyTransformer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_BodyTransformer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
};

// Vtype
struct _jc_soot_BodyTransformer$vtype {
	_jc_type			type;
	_jc_soot_BodyTransformer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_BodyTransformer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_BodyTransformer$refs {
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_BodyTransformer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_BodyTransformer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
};

// Object instance structure
struct _jc_soot_BodyTransformer$object {
	_jc_soot_BodyTransformer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_BodyTransformer$vtype	*vtype;
	_jc_soot_BodyTransformer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_BodyTransformer$vtype _jc_soot_BodyTransformer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_BodyTransformer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_BodyTransformer$class_object;

#endif	/* _JC_soot_BodyTransformer_H_ */

==> jc-1.4.6.tar.gz: soot/BodyTransformer.h <==
// public abstract class soot.BodyTransformer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer

// header file dependencies
// @dep_header soot_Transformer

#include "soot/Transformer.h"

#ifndef _JC_soot_BodyTransformer_H_
#define _JC_soot_BodyTransformer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;

// Typedefs
typedef struct _jc_soot_BodyTransformer$sub_refs	_jc_soot_BodyTransformer$sub_refs;
typedef struct _jc_soot_BodyTransformer$sub_nonrefs	_jc_soot_BodyTransformer$sub_nonrefs;
typedef struct _jc_soot_BodyTransformer$refs	_jc_soot_BodyTransformer$refs;
typedef struct _jc_soot_BodyTransformer$nonrefs	_jc_soot_BodyTransformer$nonrefs;
typedef struct _jc_soot_BodyTransformer$object	_jc_soot_BodyTransformer$object;

typedef const struct _jc_soot_BodyTransformer$vmethods	_jc_soot_BodyTransformer$vmethods;
typedef const struct _jc_soot_BodyTransformer$vtable	_jc_soot_BodyTransformer$vtable;
typedef const struct _jc_soot_BodyTransformer$vtype	_jc_soot_BodyTransformer$vtype;

// Constructors
extern void _jc_soot_BodyTransformer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_BodyTransformer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_BodyTransformer$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_BodyTransformer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_BodyTransformer$method$transform$efe210b8710809f9(_jc_env *, struct _jc_soot_BodyTransformer$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;
extern void _jc_soot_BodyTransformer$method$transform$6c1afdd3773c7636(_jc_env *, struct _jc_soot_BodyTransformer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_soot_BodyTransformer$method$transform$fa83af6c18402119(_jc_env *, struct _jc_soot_BodyTransformer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_BodyTransformer$method_info$internalTransform$9abd4924859b68a3;
extern _jc_method _jc_soot_BodyTransformer$method_info$transform$efe210b8710809f9;
extern _jc_method _jc_soot_BodyTransformer$method_info$transform$6c1afdd3773c7636;
extern _jc_method _jc_soot_BodyTransformer$method_info$transform$fa83af6c18402119;

// Virtual methods structure
struct _jc_soot_BodyTransformer$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_BodyTransformer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*transform$efe210b8710809f9)(_jc_env *, struct _jc_soot_BodyTransformer$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;
	void	(*transform$6c1afdd3773c7636)(_jc_env *, struct _jc_soot_BodyTransformer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*transform$fa83af6c18402119)(_jc_env *, struct _jc_soot_BodyTransformer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_BodyTransformer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
};

// Vtype
struct _jc_soot_BodyTransformer$vtype {
	_jc_type			type;
	_jc_soot_BodyTransformer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_BodyTransformer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_BodyTransformer$refs {
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_BodyTransformer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_BodyTransformer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
};

// Object instance structure
struct _jc_soot_BodyTransformer$object {
	_jc_soot_BodyTransformer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_BodyTransformer$vtype	*vtype;
	_jc_soot_BodyTransformer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_BodyTransformer$vtype _jc_soot_BodyTransformer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_BodyTransformer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_BodyTransformer$class_object;

#endif	/* _JC_soot_BodyTransformer_H_ */
